function [x,y] = PU_CU_cell_gen(R, R_p, U);
%% function [x_pu,y_pu,x_cu,y_cu] = PU_CU_cell_gen(R, R_p,U);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% test
% clear all;
% close all
% clc
% R = 1000;       % Outer radius of primary cell in meters
% R_p = 600;      % interference protection radius of primary cell in meters
% U = 8;          % number of users (PU + SUs)

% This function generates random users in a hexagonal and returns their
% cartesian coordinates [x, y] where the [x(1),y(1)] refers to the PU
% and [x(2:U),y(2:U)] refers to CUs with reference to the center of the cell at origin.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
x = zeros(1,U);
y = zeros(1,U);
r = R*sqrt(3)/2;
U_tot = 1e4;       % total number of users
btsx = 0;
btsy = 0;
N_cu = U -1;

%%%%%%%%%%%% Coordinates of Base Stations %%%%%%%%%%
% bx = 0;
% by = 0;

%%%%%%%%%%%% Generate Random Users %%%%%%%%%%%%%%%
%    disp('Generating random users');

%test
%while(1)
for u = 1:U_tot
    %        if ~rem(u, U / 20)
    %          disp([int2str(100 * (u - 1) / U(end)), '%']);
    %        end

    theta(u) = 2*pi*rand; % generate random angles
    rho(u) = 0;
    if theta(u) < pi/6    % generate random distances based on angle
        rho(u) = (R-50)*sin(pi/3)/(sin(pi*2/3 - theta(u)))*rand +50; %why 50 ?
    elseif theta(u) < pi/3
        rho(u) = (R-50)*sin(pi/3)/(sin(pi/3 + theta(u)))*rand + 50;
    elseif theta(u) < pi/2
        rho(u) = (r-50)/(cos(pi/2 - theta(u)))*rand + 50;
    elseif theta(u) < pi*2/3
        rho(u) = (r-50)/(cos(theta(u) - pi/2))*rand + 50;
    elseif theta(u) < pi*5/6
        rho(u) = (r-50)/(cos(pi*5/6 - theta(u)))*rand + 50;
    elseif theta(u) < pi
        rho(u) = (R-50)*sin(pi/3)/(sin(theta(u) - pi/3))*rand + 50;
    elseif theta(u) < pi*7/6
        rho(u) = (R-50)*sin(pi/3)/(sin(pi*5/3 - theta(u)))*rand + 50;
    elseif theta(u) < pi*4/3
        rho(u) = (r-50)/(cos(theta(u) - pi*7/6))*rand + 50;
    elseif theta(u) < pi*3/2
        rho(u) = (r-50)/(cos(pi*3/2 - theta(u)))*rand + 50;
    elseif theta(u) < pi*5/3
        rho(u) = (r-50)/(cos(theta(u) - pi*3/2))*rand + 50;
    elseif theta(u) < pi*11/6
        rho(u) = (r-50)/(cos(pi*11/6 - theta(u)))*rand + 50;
    elseif theta(u) < 2*pi
        rho(u) = (r-50)/(cos(theta(u) - pi*11/6))*rand + 50;
    else
        'error'
    end

    % convert to cartesian coordinates
    x(u) = rho(u)*cos(theta(u));
    y(u) = rho(u)*sin(theta(u));
    if norm([x(u) y(u)]) == 0
        disp('BTS here')
    elseif norm([x(u) y(u)]) > R_p
        x_c(u) = x(u);
        y_c(u) = y(u);
    else
        x_p(u) = x(u);
        y_p(u) = y(u);
    end
end

index_p = find(x_p~=0 & y_p~=0);
Num_pu = length(index_p);
x_pu = x_p(index_p(1:Num_pu));
y_pu = y_p(index_p(1:Num_pu));

% Num_cu SUs (x_cu,y_cu) randomly choosen among the SUs (x_c,y_c)
index_c = find(x_c~=0 & y_c~=0);
Num_cu = length(index_c);
x_cu = x_c(index_c(1:Num_cu));
y_cu = y_c(index_c(1:Num_cu));

x_cu = x_cu(1:N_cu);
y_cu = y_cu(1:N_cu);

% Only one PU (x_pu,y_pu) randomly choosen among the PUs (x_p,y_p)
p = floor(1 + (Num_pu-1) * rand(1,Num_pu));
index_pu = p(1);
x_pu = x_pu(index_pu);
y_pu = y_pu(index_pu);

x = [x_pu x_cu];
x = transpose(x);
y = [y_pu y_cu];
y = transpose(y);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%FIGURES%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %circle
% theta = linspace(0,2*pi,100);          % create vector theta
% xx = R_p*cos(theta);                   % generate x-coordinate
% yy = R_p*sin(theta);                   % generate y-coordinate

% figure
% plot(xx,yy,'LineWidth',2);             % plot PU protection area
% hold on
% plot(x_p,y_p,'b x',x_c,y_c,'r *',btsx,btsy,'r d')
% title ('original cellular system')


% figure
% plot(xx,yy,'LineWidth',2); % plot PU protection area
% hold on
% plot(x(1),y(1),'b x',x(2:end),y(2:end),'r *',btsx,btsy,'r d')
% %plot(x_pu,y_pu,'b x',x_cu,y_cu,'r *',btsx,btsy,'r d')
% title ('PU_CU system')