function [path_loss, distUser] = propagation_model_CR_uplink(x,y,R_p,alpha)

% [path_loss, distUserBTS] = propagation_model(x, y)
% Calculates path loss according to COST-231 model between cartesian coordinates (x,y) and
% base station at coordinates at the origin. distUserBTS is the scalar
% distances between the coordinates and:
% the BTS for PU's signal,
% the SU_Tx and a virtual SU_Rx located at a distance (R_p-alpha) from the
% SU for SU's signal,
% different users for interference.
%Saad system model treats the downlink commnication with diferent BTS, giving rise to
%interference from other cells. We thus need distances between users and BTS.
%Here we study the uplink system with only one cell. Interference comes from
%other users during an uplink communication. We thus need distances between
%all users.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f0 = 1800;      % carrier frequency in MHz
hb = 30;        % BS height in meters
hu = 1;         % terminal height in meters
U = length(x);  % PU + SUs
distUser = zeros(U);

%Test
% R_p = 600; %in meters
% alpha = 50; %in meters

%disp('Calculating distances between users');
for ii = 1:U
    for jj = 1:U
        if ii ~= jj%interference
            if ii == 1%BS: SU_Tx(jj) to BS
                distUser(ii,jj) = sqrt( (x(ii)).^2 + (y(ii)).^2);
            else%SU: PU to SU_Rx
                distUser(ii,jj) = sqrt( (x(ii) - x(jj)).^2 + (y(ii) - y(jj)).^2 + ...
                    (1 + (R_p-alpha-1) * rand(1))^2 );%pithagore
            end
        else%signal
            if ii == 1%PU
                distUser(ii,jj) = sqrt(x(ii)^2 + y(ii)^2);
            else %SUs
                distUser(ii,jj) = 1 + (R_p-alpha-1) * rand(1);
            end
        end
    end
end

% while(1)
c_hr_smallmedcities = ...
    (1.1 * log10(f0) - 0.7) * hu - (1.56 * log10(f0) - 0.8); % dB
c_hr_largecities = 3.2 * (log10(11.75 * hu))^2 - 4.97;     % dB

Cm = 0; % 3 dB in metrop. centers, 0 dB in medium sized cities and sub.areas
L_user = 46.3 + 33.9*log10(f0) - 13.82*log10(hb) - c_hr_smallmedcities + ...
    (44.9 - 6.55 * log10(hb)) ...
    * log10(distUser / 1000) + Cm;  % COST-231 model for small medium city

path_loss = L_user; % adding shadowing factor


